@@ -80,7 +80,7 @@ class Instalador(InstaladorBase):
         headers = {
             'Accept': 'application/json',
             'User-Agent': 'LI-Pagador_MercadoPago-{}v'.format(pagador_mercadopago.__version__),
-            'Content-type': 'application/json'
+            'Content-type': 'application/x-www-form-urlencoded'
         }
         resposta = requests.post(url, params=dados, headers=headers)
         if resposta.status_code == 200:
